cleanAndPivot: Remove NA columns from dataframe and convert to long format

Description Usage Arguments Value

View source: R/utility.R

Description

Remove NA columns from dataframe and convert to long format

Usage

1

Arguments

df

dataframe with dose response data. The first column needs to be the concentration.

Value

long dataframe


alxbetz/drfit documentation built on Aug. 1, 2020, 9:44 a.m.