plot_replicate_drc: Plot a single dose response curve with standard deviation of...

Description Usage Arguments Value

View source: R/plotting.R

Description

Plot a single dose response curve with standard deviation of replicates

Usage

1
plot_replicate_drc(fitObject)

Arguments

fitObject

bendr fit object

Value

ggplot object


alxbetz/drfit documentation built on Aug. 1, 2020, 9:44 a.m.